/**
 * 
 */
package org.gcube.portlets.user.td.csvexportwidget.client;



import org.gcube.portlets.user.td.gwtservice.shared.csv.CSVExportSession;
import org.gcube.portlets.user.td.gwtservice.shared.destination.FileDestination;
import org.gcube.portlets.user.td.gwtservice.shared.destination.WorkspaceDestination;
import org.gcube.portlets.user.td.wizardwidget.client.WizardCard;

import com.allen_sauer.gwt.log.client.Log;
import com.google.gwt.event.logical.shared.ValueChangeEvent;
import com.google.gwt.event.logical.shared.ValueChangeHandler;
import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.ui.HasValue;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.sencha.gxt.core.client.util.ToggleGroup;
import com.sencha.gxt.widget.core.client.form.Radio;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class DestinationSelectionCard extends WizardCard {

	protected final CSVExportSession exportSession;

	final FileDestination fileDestination = FileDestination.INSTANCE;
	final WorkspaceDestination workspaceDestination = WorkspaceDestination.INSTANCE;

	public DestinationSelectionCard(final CSVExportSession exportSession) {
		super("CSV destination selection", "");

		this.exportSession = exportSession;
		// Default
		exportSession.setDestination(fileDestination);

		VerticalPanel destinationSelectionPanel = new VerticalPanel();
		destinationSelectionPanel.setStylePrimaryName(res.wizardCSS()
				.getImportSelectionSources());

		Radio radioFileSource = new Radio();
		radioFileSource.setBoxLabel("<p style='display:inline-table;'><b>"
				+ fileDestination.getName() + "</b><br>"
				+ fileDestination.getDescription() + "</p>");
		radioFileSource.setName(fileDestination.getName());
		radioFileSource.setStylePrimaryName(res.wizardCSS()
				.getImportSelectionSource());
		radioFileSource.setValue(true);

		Radio radioWorkspaceSource = new Radio();
		radioWorkspaceSource.setBoxLabel("<p style='display:inline-table;'><b>"
				+ workspaceDestination.getName() + "</b><br>"
				+ workspaceDestination.getDescription() + "</p>");
		radioWorkspaceSource.setName(workspaceDestination.getName());
		radioWorkspaceSource.setStylePrimaryName(res.wizardCSS()
				.getImportSelectionSource());
		// radioWorkspaceSource.disable();

		destinationSelectionPanel.add(radioFileSource);
		destinationSelectionPanel.add(radioWorkspaceSource);

		// we can set name on radios or use toggle group
		ToggleGroup toggle = new ToggleGroup();
		toggle.add(radioWorkspaceSource);
		toggle.add(radioFileSource);

		toggle.addValueChangeHandler(new ValueChangeHandler<HasValue<Boolean>>() {

			@Override
			public void onValueChange(ValueChangeEvent<HasValue<Boolean>> event) {
				try {
					ToggleGroup group = (ToggleGroup) event.getSource();
					Radio radio = (Radio) group.getValue();
					Log.info("Source Selected:" + radio.getName());
					if (radio.getName().compareTo(workspaceDestination.getName()) == 0) {
						exportSession.setDestination(workspaceDestination);
					} else {
						if (radio.getName().compareTo(fileDestination.getName()) == 0) {
							exportSession.setDestination(fileDestination);
						} else {

						}

					}

				} catch (Exception e) {
					Log.error("ToggleGroup: onValueChange "
							+ e.getLocalizedMessage());
				}

			}
		});

		setContent(destinationSelectionPanel);

	}

	@Override
	public void setup() {
		Log.debug("Setup Card");
		Command sayNextCard = new Command() {
			public void execute() {
				try {
					String sourceId = exportSession.getDestination().getId();
					if (sourceId == null || sourceId.isEmpty()) {
						Log.error("CSV Import Source Id: " + sourceId);
					} else {
						if (sourceId.compareTo("File") == 0) {
							Log.info("NextCard CSVUploadFileCard");
							DownloadFileCard downloadFileCard = new DownloadFileCard(
									exportSession);
							getWizardWindow().addCard(downloadFileCard);
							getWizardWindow().nextCard();
						} else {
							if (sourceId.compareTo("Workspace") == 0) {
								Log.info("NextCard CSVWorkspaceSelectionCard");
								/*CSVWorkSpaceSelectionCard csvWorkspaceSelectionCard = new CSVWorkSpaceSelectionCard(
										importSession);
								getWizardWindow().addCard(
										csvWorkspaceSelectionCard);*/
								getWizardWindow().nextCard();
							} else {
								Log.debug("No source selected and no card loaded");
							}
						}
					}
				} catch (Exception e) {
					Log.error("sayNextCard :" + e.getLocalizedMessage());
				}
			}
		};

		getWizardWindow().setNextButtonCommand(sayNextCard);

	}

}
